@@ -98,6 +98,7 @@ class HeatControl:
         self.highest_prices = []
         self.lowest_prices = []
         self.hour_prices = []
+        self.initialize_gpio()
 
         self.new_day(False)
 
@@ -128,13 +129,18 @@ class HeatControl:
         self.hour_prices.sort(key=lambda x: x["Rank"])
         for hour in self.hour_prices:
             print(str(hour["Hour"]) + " " + str(hour["PriceNoTax"]))
+    
+    def initialize_gpio(self):
+        GPIO.cleanup()
+        GPIO.setmode(GPIO.BCM)
+        GPIO.setup(GPIO_HALF_POWER, GPIO.OUT)
+        GPIO.setup(GPIO_ZERO_POWER, GPIO.OUT)
+        GPIO.output(GPIO_HALF_POWER, False)
+        GPIO.output(GPIO_ZERO_POWER, False)
 
     def set_rasbperry_pi_gpio_pin(self, pin_number, state):
 
-        GPIO.setmode(GPIO.BCM)
-        GPIO.setup(pin_number, GPIO.OUT)
         GPIO.output(pin_number, state)
-        GPIO.cleanup()
 
     def set_heat_50_percent(self):
         self.set_rasbperry_pi_gpio_pin(GPIO_HALF_POWER , True)
